import os
from sqlalchemy import create_engine
from sqlalchemy.orm import scoped_session, sessionmaker
from sqlalchemy.ext.declarative import declarative_base


def _get_credentials():
    result = {
        'postgresHost': os.getenv(
            'AACT_HOST',
            'aact-db.cfsmp5gaqyau.us-east-1.rds.amazonaws.com'),
        'postgresUser': os.getenv('AACT_USER', 'root'),
        'postgresPassword': os.getenv('AACT_PASSWORD', 'aactpass'),
        'postgresDB': os.getenv('AACT_DB', 'aact'),
        'postgresPort': os.getenv('AACT_PORT', 5432),
    }
    return result


def _get_postgres_uri():
    credentials = _get_credentials()
    return 'postgres+psycopg2://{user}:{password}@{host}:{port}/{db}'.format(
        user=credentials['postgresUser'],
        password=credentials['postgresPassword'],
        host=credentials['postgresHost'],
        port=credentials['postgresPort'],
        db=credentials['postgresDB'],
    )


postgres_db_uri = _get_postgres_uri()
engine = create_engine(
    postgres_db_uri,
    convert_unicode=True,
)

db_session = scoped_session(
    sessionmaker(
        autocommit=False,
        autoflush=False,
        bind=engine,
    ),
)

Base = declarative_base()
Base.query = db_session.query_property()



from datetime import datetime

from sqlalchemy import (
    Column,
    Integer,
    String,
    DateTime,
    UniqueConstraint,
    ForeignKey,
)

from ...database import Base


class NDCModel(Base):
    __tablename__ = "ndc"

    id = Column(Integer, primary_key=True)
    spl_id = Column(String(128), nullable=False)
    appl_no = Column(String(128), nullable=False)
    appl_type = Column(String(128), nullable=False)
    spl_set_id = Column(String(128), nullable=True)
    product_ndc = Column(String(128), nullable=True, index=True)
    route = Column(String(128), nullable=True, index=True)
    dosage_form = Column(String(128), nullable=True)
    generic_name = Column(String(128), nullable=True)
    labeler_name = Column(String(128), nullable=True)
    labeler_subsidiary_id = Column(
        Integer, ForeignKey("subsidiaries.id"), nullable=True,
    )
    brand_name = Column(String(128), nullable=True)
    marketing_category = Column(String(128), nullable=True)
    updated_at = Column(
        DateTime,
        nullable=False,
        default=datetime.utcnow,
        onupdate=datetime.utcnow,
    )

    __table_args__ = (UniqueConstraint("spl_id", "product_ndc",),)



from sqlalchemy import (
    Column,
    Integer,
    String,
    DateTime,
    UniqueConstraint,
)
from datetime import datetime

from ...database import Base


class CompanyOUSModel(Base):
    __tablename__ = 'companies_ous'

    id = Column(Integer, primary_key=True)
    name = Column(String(190), unique=True, nullable=False)
    ticker = Column(String(20), nullable=True, index=True)
    exchange = Column(String(100), nullable=True)
    updated_at = Column(
        DateTime,
        nullable=False,
        default=datetime.utcnow,
        onupdate=datetime.utcnow,
    )



from datetime import datetime

from sqlalchemy import (
    Column,
    Integer,
    String,
    DateTime,
)

from ...database import Base


class DrugIndicationModel(Base):
    __tablename__ = "drug_indications"

    id = Column(Integer, primary_key=True)
    set_id = Column(String(128), nullable=False, index=True)
    lowercase_indication = Column(String(128), nullable=False, index=True)
    indication = Column(String(128), nullable=False)
    updated_at = Column(
        DateTime,
        nullable=False,
        default=datetime.utcnow,
        onupdate=datetime.utcnow,
    )
